@@ -35,7 +35,6 @@ Copyright_License {
 #include "NativePortListener.hpp"
 #include "NativeInputListener.hpp"
 #include "TextUtil.hpp"
-#include "LogCat.hpp"
 #include "Product.hpp"
 #include "Nook.hpp"
 #include "Language/Language.hpp"
@@ -188,13 +187,6 @@ Java_org_xcsoar_NativeView_initializeNative(JNIEnv *env, jobject obj,
   return Startup();
 }
 
-void
-OnLogCatFinished(bool crash_found)
-{
-  if (crash_found)
-    CommonInterface::main_window->SendCrash();
-}
-
 gcc_visibility_default
 JNIEXPORT void JNICALL
 Java_org_xcsoar_NativeView_runNative(JNIEnv *env, jobject obj)
@@ -203,8 +195,6 @@ Java_org_xcsoar_NativeView_runNative(JNIEnv *env, jobject obj)
 
   OpenGL::Initialise();
 
-  CheckLogCat(*io_thread);
-
   CommonInterface::main_window->RunEventLoop();
 }
 
@@ -218,8 +208,6 @@ Java_org_xcsoar_NativeView_deinitializeNative(JNIEnv *env, jobject obj)
     Nook::ExitFastMode();
   }
 
-  StopLogCat();
-
   InitThreadDebug();
 
   if (CommonInterface::main_window != nullptr) {
