@@ -160,6 +160,10 @@ CirclingComputer::Turning(CirclingInfo &circling_info,
     if (!force_circling)
       break;
 
+#if GCC_CHECK_VERSION(7,0)
+    [[fallthrough]];
+#endif
+
   case CirclingMode::POSSIBLE_CLIMB:
     if (force_cruise) {
       circling_info.turn_mode = CirclingMode::CRUISE;
@@ -201,6 +205,10 @@ CirclingComputer::Turning(CirclingInfo &circling_info,
     if (!force_cruise)
       break;
 
+#if GCC_CHECK_VERSION(7,0)
+    [[fallthrough]];
+#endif
+
   case CirclingMode::POSSIBLE_CRUISE:
     if (force_circling) {
       circling_info.turn_mode = CirclingMode::CLIMB;
