@@ -474,6 +474,13 @@ CAI302::DownloadNavpoint(Port &port, const GeoPoint &location,
   return DownloadCommand(port, buffer, env);
 }
 
+bool
+CAI302::CloseNavpoints(Port &port, OperationEnvironment &env)
+{
+  return DownloadCommand(port, "C,-1\r", env, 5000);
+}
+
+
 bool
 CAI302::DeclareTP(Port &port, unsigned i, const GeoPoint &location,
                   int altitude, const char *name, OperationEnvironment &env)
