@@ -30,6 +30,7 @@ Copyright_License {
 #include "Form/DataField/Listener.hpp"
 #include "Language/Language.hpp"
 #include "Tracking/TrackingSettings.hpp"
+#include "Tracking/SkyLines/Key.hpp"
 #include "Net/State.hpp"
 #include "Form/DataField/Base.hpp"
 #include "Widget/RowFormWidget.hpp"
@@ -50,6 +51,7 @@ enum ControlIndex {
   SL_NEAR_TRAFFIC_ENABLED,
 #endif
   SL_KEY,
+  CLOUD_ENABLED,
 #endif
 #if defined(HAVE_SKYLINES_TRACKING) && defined(HAVE_LIVETRACK24)
   SPACER,
@@ -227,6 +229,11 @@ TrackingConfigPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
   else
     buffer.clear();
   AddText(_T("Key"), nullptr, buffer);
+
+  AddBoolean(_T("XCSoar Cloud"),
+             _("Participate in the XCSoar Cloud field test?  This transmits your location, thermal/wave locations and other weather data to our test server."),
+             settings.skylines.cloud_enabled == TriState::TRUE,
+             this);
 #endif
 
 #if defined(HAVE_SKYLINES_TRACKING) && defined(HAVE_LIVETRACK24)
@@ -316,6 +323,25 @@ TrackingConfigPanel::Save(bool &_changed)
 
   changed |= SaveKey(*this, SL_KEY, ProfileKeys::SkyLinesTrackingKey,
                      settings.skylines.key);
+
+  bool cloud_enabled = settings.skylines.cloud_enabled == TriState::TRUE;
+  if (SaveValue(CLOUD_ENABLED, ProfileKeys::CloudEnabled, cloud_enabled)) {
+    settings.skylines.cloud_enabled = cloud_enabled
+      ? TriState::TRUE
+      : TriState::FALSE;
+
+    if (settings.skylines.cloud_enabled == TriState::TRUE &&
+        settings.skylines.cloud_key == 0) {
+      settings.skylines.cloud_key = SkyLinesTracking::GenerateKey();
+
+      char s[64];
+      snprintf(s, sizeof(s), "%llx",
+               (unsigned long long)settings.skylines.cloud_key);
+      Profile::Set(ProfileKeys::CloudKey, s);
+    }
+
+    changed = true;
+  }
 #endif
 
 #ifdef HAVE_LIVETRACK24
