@@ -57,6 +57,7 @@ FlarmTrafficWindow::FlarmTrafficWindow(const FlarmTrafficLook &_look,
    side_display_type(SIDE_INFO_VARIO)
 {
   data.Clear();
+  data_modified.Clear();
 }
 
 bool
@@ -186,6 +187,12 @@ void
 FlarmTrafficWindow::Update(Angle new_direction, const TrafficList &new_data,
                            const TeamCodeSettings &new_settings)
 {
+  static constexpr Angle min_heading_delta = Angle::Degrees(2);
+  if (new_data.modified == data_modified &&
+      (heading - new_direction).Absolute() < min_heading_delta)
+    /* no change - don't redraw */
+    return;
+
   FlarmId selection_id;
   RasterPoint pt;
   if (!small && selection >= 0) {
@@ -197,6 +204,7 @@ FlarmTrafficWindow::Update(Angle new_direction, const TrafficList &new_data,
     pt.y = -100;
   }
 
+  data_modified = new_data.modified;
   heading = new_direction;
   fr.SetAngle(-heading);
   fir.SetAngle(heading);
