@@ -51,7 +51,7 @@ ShowNextWaypointDetails()
   if (wp == nullptr)
     return;
 
-  dlgWaypointDetailsShowModal(*wp);
+  dlgWaypointDetailsShowModal(*wp, false);
 }
 
 static Widget *
@@ -498,12 +498,8 @@ UpdateInfoBoxTaskSpeed(InfoBoxData &data)
     return;
   }
 
-  // Set Value
-  data.SetValue(_T("%2.0f"),
-                    Units::ToUserTaskSpeed(task_stats.total.travelled.GetSpeed()));
-
-  // Set Unit
-  data.SetValueUnit(Units::current.task_speed_unit);
+  // Set Value and unit
+  data.SetValueFromTaskSpeed(task_stats.total.travelled.GetSpeed());
 }
 
 void
@@ -516,12 +512,8 @@ UpdateInfoBoxTaskSpeedAchieved(InfoBoxData &data)
     return;
   }
 
-  // Set Value
-  data.SetValue(_T("%2.0f"),
-                    Units::ToUserTaskSpeed(task_stats.total.remaining_effective.GetSpeed()));
-
-  // Set Unit
-  data.SetValueUnit(Units::current.task_speed_unit);
+  // Set Value and unit
+  data.SetValueFromTaskSpeed(task_stats.total.remaining_effective.GetSpeed());
 }
 
 void
@@ -534,11 +526,7 @@ UpdateInfoBoxTaskSpeedInstant(InfoBoxData &data)
   }
 
   // Set Value
-  data.SetValue(_T("%2.0f"),
-                    Units::ToUserTaskSpeed(task_stats.get_pirker_speed()));
-
-  // Set Unit
-  data.SetValueUnit(Units::current.task_speed_unit);
+  data.SetValueFromTaskSpeed(task_stats.get_pirker_speed());
 }
 
 void
@@ -551,8 +539,8 @@ UpdateInfoBoxTaskSpeedHour(InfoBoxData &data)
     return;
   }
 
-  data.SetValue(_T("%2.0f"), Units::ToUserTaskSpeed(window.speed));
-  data.SetValueUnit(Units::current.task_speed_unit);
+  // Set Value and unit
+  data.SetValueFromTaskSpeed(window.speed);
 }
 
 void
@@ -692,12 +680,8 @@ UpdateInfoBoxTaskAASpeed(InfoBoxData &data)
     return;
   }
 
-  // Set Value
-  data.SetValue(_T("%2.0f"),
-                    Units::ToUserTaskSpeed(common_stats.aat_speed_target));
-
-  // Set Unit
-  data.SetValueUnit(Units::current.task_speed_unit);
+  // Set Value and units
+  data.SetValueFromTaskSpeed(common_stats.aat_speed_target);
 }
 
 void
@@ -712,12 +696,8 @@ UpdateInfoBoxTaskAASpeedMax(InfoBoxData &data)
     return;
   }
 
-  // Set Value
-  data.SetValue(_T("%2.0f"),
-                    Units::ToUserTaskSpeed(common_stats.aat_speed_max));
-
-  // Set Unit
-  data.SetValueUnit(Units::current.task_speed_unit);
+  // Set Value and units
+  data.SetValueFromTaskSpeed(common_stats.aat_speed_max);
 }
 
 void
@@ -733,12 +713,8 @@ UpdateInfoBoxTaskAASpeedMin(InfoBoxData &data)
     return;
   }
 
-  // Set Value
-  data.SetValue(_T("%2.0f"),
-                    Units::ToUserTaskSpeed(common_stats.aat_speed_min));
-
-  // Set Unit
-  data.SetValueUnit(Units::current.task_speed_unit);
+  // Set Value and units
+  data.SetValueFromTaskSpeed(common_stats.aat_speed_min);
 }
 
 void
@@ -784,7 +760,6 @@ UpdateInfoBoxNextETEVMG(InfoBoxData &data)
   const fixed v = basic.ground_speed;
 
   if (!task_stats.task_valid ||
-      !positive(d) ||
       !positive(v)) {
     data.SetInvalid();
     return;
@@ -815,7 +790,6 @@ UpdateInfoBoxFinalETEVMG(InfoBoxData &data)
   const fixed v = basic.ground_speed;
 
   if (!task_stats.task_valid ||
-      !positive(d) ||
       !positive(v)) {
     data.SetInvalid();
     return;
