@@ -528,7 +528,7 @@ InfoBoxWindow::OnMouseMove(PixelScalar x, PixelScalar y, unsigned keys)
 }
 
 void
-InfoBoxWindow::OnPaint(Canvas &canvas)
+InfoBoxWindow::OnPaintBuffer(Canvas &canvas)
 {
   Paint(canvas);
 }
