@@ -668,6 +668,8 @@ Shutdown()
 
   LogFormat("Close Windows - main");
   main_window->Destroy();
+  delete main_window;
+  CommonInterface::main_window = nullptr;
 
   CloseLanguageFile();
 
