@@ -95,6 +95,11 @@ MakeWaypoint(const TCHAR *name, int altitude,
   return wp;
 }
 
+#ifdef __clang__
+/* true, the nullptr cast below is a bad kludge */
+#pragma GCC diagnostic ignored "-Wnull-dereference"
+#endif
+
 int main(int argc, char **argv)
 {
   Args args(argc, argv, "[--through DRIVER0] DRIVER PORT BAUD");
